@@ -34,7 +34,6 @@
 #include "ephy-embed-single.h"
 #include "ephy-embed-prefs.h"
 #include "ephy-embed-utils.h"
-#include "ephy-file-chooser.h"
 #include "ephy-file-helpers.h"
 #include "ephy-history.h"
 #include "ephy-prefs.h"
@@ -498,9 +497,6 @@ ephy_embed_constructed (GObject *object)
   GtkWidget *overlay;
   EphyOverlayEscapingChild *escaping_child;
   GtkWidget *frame;
-  GtkCssProvider *provider;
-  GtkStyleContext *context;
-  GError *error = NULL;
 
   /* Skeleton */
   web_view = WEBKIT_WEB_VIEW (ephy_web_view_new ());
@@ -511,18 +507,6 @@ ephy_embed_constructed (GObject *object)
   priv->statusbar_label = gtk_label_new (NULL);
   frame = gtk_frame_new (NULL);
   gtk_widget_set_name (frame, "ephy-status-frame");
-  provider = gtk_css_provider_new ();
-  gtk_css_provider_load_from_data (provider,
-                                   "#ephy-status-frame { border-style: solid; border-width: 1; padding: 4; }",
-                                   -1, &error);
-  if (error == NULL) {
-    context = gtk_widget_get_style_context (frame);
-    gtk_style_context_add_provider (context, GTK_STYLE_PROVIDER (provider),
-                                    GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
-  } else
-    g_error_free (error);
-
-  g_object_unref (provider);
 
   gtk_widget_show (frame);
     
